{
    "$graph": [
        {
            "class": "CommandLineTool",
            "id": "#Dockstore.cwl",
            "label": "CGP file checksum generator",
            "doc": "![build_status](https://quay.io/repository/wtsicgp/dockstore-cgp-chksum/status)\nA Docker container for producing file md5sum and sha512sum. See the [dockstore-cgp-chksum](https://github.com/cancerit/dockstore-cgp-chksum) website for more information.\n",
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "quay.io/wtsicgp/dockstore-cgp-chksum:0.4.1"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "-A",
                        "position": 5
                    },
                    "doc": "Flag to suppress all curl exit status",
                    "id": "#Dockstore.cwl/cgp-chksum/ignore_all_curl_exits"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "int",
                            "inputBinding": {
                                "prefix": "-E",
                                "separate": true,
                                "shellQuote": true
                            }
                        }
                    ],
                    "doc": "Optional curl exit codes to suppress",
                    "inputBinding": {
                        "position": 4
                    },
                    "id": "#Dockstore.cwl/cgp-chksum/ignore_curl_exits"
                },
                {
                    "type": "File",
                    "doc": "file to have checksum generated from",
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-i",
                        "separate": true,
                        "shellQuote": true
                    },
                    "id": "#Dockstore.cwl/cgp-chksum/in_file"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "doc": "use as chksum output instead of generating a new one.",
                    "inputBinding": {
                        "position": 6,
                        "prefix": "-j",
                        "separate": true,
                        "shellQuote": true
                    },
                    "id": "#Dockstore.cwl/cgp-chksum/in_json"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "doc": "Optional PUT address to send JSON results",
                    "inputBinding": {
                        "position": 2,
                        "prefix": "-p",
                        "separate": true,
                        "shellQuote": true
                    },
                    "id": "#Dockstore.cwl/cgp-chksum/put_address"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string",
                            "inputBinding": {
                                "prefix": "-H",
                                "separate": true,
                                "shellQuote": true
                            }
                        }
                    ],
                    "doc": "Optional headers to send with JSON results",
                    "inputBinding": {
                        "position": 3
                    },
                    "id": "#Dockstore.cwl/cgp-chksum/put_headers"
                }
            ],
            "baseCommand": [
                "/opt/wtsi-cgp/bin/sums2json.sh"
            ],
            "http://purl.org/dc/terms/creator": {
                "@id": "yaobo.xu@sanger.ac.uk",
                "foaf:name": "Yaobo Xu",
                "foaf:mbox": "yx2@sanger.ac.uk"
            },
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.in_file.basename).check_sums.json"
                    },
                    "id": "#Dockstore.cwl/cgp-chksum/chksum_json"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "$(inputs.in_file.basename).server_response.txt"
                    },
                    "id": "#Dockstore.cwl/cgp-chksum/server_response"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "id": "#xam_to_interleaved_by_rg.cwl",
            "label": "CGP [B|Cr]am to interleaved fastq by read group",
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "quay.io/wtsicgp/dockstore-samtools-biobambam2:0.0.5"
                }
            ],
            "inputs": [
                {
                    "type": "string",
                    "doc": "Prefix string to prepend to all output .fq.gz file names",
                    "default": "rg_split",
                    "inputBinding": {
                        "position": 2,
                        "shellQuote": true
                    },
                    "id": "#xam_to_interleaved_by_rg.cwl/cgp-xam-to-ifq/output_prefix"
                },
                {
                    "type": "string",
                    "doc": "URL to use for cram reference e.g. 'https://www.ebi.ac.uk/ena/cram/md5/%s'",
                    "default": "https://www.ebi.ac.uk/ena/cram/md5/%s",
                    "inputBinding": {
                        "position": 3,
                        "shellQuote": true
                    },
                    "id": "#xam_to_interleaved_by_rg.cwl/cgp-xam-to-ifq/ref_path"
                },
                {
                    "type": "string",
                    "doc": "Filename for the json file containing RG info (ID, PU, CN, LB, DT tags)",
                    "default": "rg_info.json",
                    "inputBinding": {
                        "position": 4,
                        "shellQuote": true
                    },
                    "id": "#xam_to_interleaved_by_rg.cwl/cgp-xam-to-ifq/rg_info_out"
                },
                {
                    "type": "File",
                    "doc": "Bam/Cram input file to be split into interleaved fastq split by read group",
                    "inputBinding": {
                        "position": 1,
                        "shellQuote": true
                    },
                    "id": "#xam_to_interleaved_by_rg.cwl/cgp-xam-to-ifq/xam_in"
                }
            ],
            "outputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "doc": "Array of gzipped interleaved fastq output files. One per readgroup.",
                    "outputBinding": {
                        "glob": "$(inputs.output_prefix)*_i.fq.gz"
                    },
                    "id": "#xam_to_interleaved_by_rg.cwl/cgp-xam-to-ifq/ifastqs_out"
                },
                {
                    "type": "File",
                    "doc": "json file containing RG line information",
                    "outputBinding": {
                        "glob": "$(inputs.rg_info_out)"
                    },
                    "id": "#xam_to_interleaved_by_rg.cwl/cgp-xam-to-ifq/rg_info_json"
                }
            ],
            "baseCommand": [
                "splitXamToInterleaved.sh"
            ],
            "doc": "![build_status](https://quay.io/repository/wtsicgp/dockstore-samtools-biobambam2/status)\nA Docker container for samtools and biobambam operations. Script provided for xam to interleaved fastq.\n\nSee the dockstore-samtools-biobambam2 [README](https://github.com/cancerit/dockstore-samtools-biobambam2/blob/develop/README.md)\nfor full details of how to use.\n",
            "http://schema.org/codeRepository": "https://github.com/cancerit/dockstore-samtools-biobambam2",
            "http://schema.org/license": "https://spdx.org/licenses/AGPL-3.0",
            "http://schema.org/author": [
                {
                    "class": "http://schema.org/Person",
                    "http://schema.org/identifier": "https://orcid.org/0000-0002-0407-0386",
                    "http://schema.org/email": "mailto:cgphelp@sanger.ac.uk",
                    "http://schema.org/name": "David Jones"
                }
            ]
        },
        {
            "class": "Workflow",
            "id": "#main",
            "label": "A CGP workflow to generate checksum and interleaved fastq from a [Cr|B]am file",
            "requirements": [
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                },
                {
                    "class": "ScatterFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "string",
                    "doc": "URL path to use as cram reference e.g. 'https://www.ebi.ac.uk/ena/cram/md5/%s'",
                    "default": "https://www.ebi.ac.uk/ena/cram/md5/%s",
                    "id": "#main/cram_ref_url"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "doc": "Optional PUT address to send JSON results of checksums",
                    "id": "#main/put_address"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string"
                        }
                    ],
                    "doc": "Optional headers to send with JSON results",
                    "id": "#main/put_headers"
                },
                {
                    "type": "File",
                    "doc": "The [B|Cr]am file to import.",
                    "id": "#main/xam_in"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#main/chksum/chksum_json",
                    "id": "#main/chksum_json"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputSource": "#main/chksum/server_response",
                    "id": "#main/chksum_put_server_response"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "doc": "Array of gzipped interleaved fastq files, one per read group in xam_in",
                    "outputSource": "#main/xam_to_interleaved_fq/ifastqs_out",
                    "id": "#main/interleaved_fastq_out"
                },
                {
                    "type": "File",
                    "outputSource": "#main/manifest_string_to_file/outfile",
                    "id": "#main/results_manifest"
                }
            ],
            "steps": [
                {
                    "in": [
                        {
                            "valueFrom": "$(true)",
                            "id": "#main/chksum/ignore_all_curl_exits"
                        },
                        {
                            "source": "#main/xam_in",
                            "id": "#main/chksum/in_file"
                        },
                        {
                            "source": "#main/put_address",
                            "id": "#main/chksum/put_address"
                        },
                        {
                            "source": "#main/put_headers",
                            "id": "#main/chksum/put_headers"
                        }
                    ],
                    "out": [
                        "#main/chksum/chksum_json",
                        "#main/chksum/server_response"
                    ],
                    "run": "#Dockstore.cwl",
                    "id": "#main/chksum"
                },
                {
                    "in": [
                        {
                            "source": [
                                "#main/results_manifest_string/out_string"
                            ],
                            "id": "#main/manifest_string_to_file/in_string"
                        }
                    ],
                    "out": [
                        "#main/manifest_string_to_file/outfile"
                    ],
                    "run": "#string_to_file.cwl",
                    "id": "#main/manifest_string_to_file"
                },
                {
                    "in": [
                        {
                            "source": "#main/xam_to_interleaved_fq/ifastqs_out",
                            "id": "#main/out_chksum/in_file"
                        }
                    ],
                    "scatter": [
                        "#main/out_chksum/in_file"
                    ],
                    "scatterMethod": "dotproduct",
                    "out": [
                        "#main/out_chksum/chksum_json"
                    ],
                    "run": "#Dockstore.cwl",
                    "id": "#main/out_chksum"
                },
                {
                    "in": [
                        {
                            "source": [
                                "#main/chksum/chksum_json"
                            ],
                            "linkMerge": "merge_flattened",
                            "id": "#main/results_manifest_string/input_chksum_results"
                        },
                        {
                            "source": [
                                "#main/xam_in"
                            ],
                            "linkMerge": "merge_flattened",
                            "id": "#main/results_manifest_string/input_files"
                        },
                        {
                            "source": "#main/out_chksum/chksum_json",
                            "id": "#main/results_manifest_string/output_chksum_results"
                        },
                        {
                            "source": "#main/xam_to_interleaved_fq/ifastqs_out",
                            "id": "#main/results_manifest_string/output_files"
                        },
                        {
                            "source": "#main/xam_to_interleaved_fq/rg_info_json",
                            "id": "#main/results_manifest_string/output_rg_info_file"
                        }
                    ],
                    "out": [
                        "#main/results_manifest_string/out_string"
                    ],
                    "run": "#results_manifest.cwl",
                    "id": "#main/results_manifest_string"
                },
                {
                    "in": [
                        {
                            "source": "#main/cram_ref_url",
                            "id": "#main/xam_to_interleaved_fq/ref_path"
                        },
                        {
                            "source": "#main/xam_in",
                            "id": "#main/xam_to_interleaved_fq/xam_in"
                        }
                    ],
                    "out": [
                        "#main/xam_to_interleaved_fq/ifastqs_out",
                        "#main/xam_to_interleaved_fq/rg_info_json"
                    ],
                    "run": "#xam_to_interleaved_by_rg.cwl",
                    "id": "#main/xam_to_interleaved_fq"
                }
            ],
            "doc": "A workflow to generate checksums of [B|Cr]am files and interleaved FastQs derived from them. See the [workflow-seq-import](https://github.com/cancerit/workflow-seq-import) website for more information.\n",
            "http://schema.org/codeRepository": "https://github.com/cancerit/workflow-seq-import",
            "http://schema.org/license": "https://spdx.org/licenses/AGPL-3.0",
            "http://schema.org/author": [
                {
                    "class": "http://schema.org/Person",
                    "http://schema.org/identifier": "https://orcid.org/0000-0002-0407-0386",
                    "http://schema.org/email": "mailto:drj@sanger.ac.uk",
                    "http://schema.org/name": "David Jones"
                }
            ],
            "http://purl.org/dc/terms/creator": {
                "foaf:name": "David Jones",
                "foaf:mbox": "genservhelp@sanger.ac.uk"
            }
        },
        {
            "class": "ExpressionTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File",
                        "inputBinding": {
                            "loadContents": true
                        }
                    },
                    "id": "#results_manifest.cwl/input_chksum_results"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#results_manifest.cwl/input_files"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File",
                        "inputBinding": {
                            "loadContents": true
                        }
                    },
                    "id": "#results_manifest.cwl/output_chksum_results"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#results_manifest.cwl/output_files"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "loadContents": true
                    },
                    "id": "#results_manifest.cwl/output_rg_info_file"
                }
            ],
            "outputs": [
                {
                    "type": "string",
                    "id": "#results_manifest.cwl/out_string"
                }
            ],
            "expression": "${\n  function name_and_chksum(files, chksum_out_json_files) {\n    var metas = [];\n    for (var i=0; i<files.length; i++) {\n      var temp_obj = JSON.parse(chksum_out_json_files[i].contents);\n      metas.push({name: files[i].basename, size: files[i].size, md5: temp_obj.md5sum, sha2: temp_obj.sha2sum});\n    }\n    return metas;\n  }\n\n  function name_and_checksum_and_rg(files, chksum_out_json_files, rg_info_file){\n    var metas = [];\n    var rg_obj = JSON.parse(rg_info_file.contents);\n    var rg_dict = {};\n    for(var j=0; j<rg_obj.length; j++){ \n      rg_dict[rg_obj[j][\"ID\"]] = rg_obj[j];   \n    }\n    for (var i=0; i<files.length; i++) {\n      //Use file basename e.g. rg_split_10659_i.fq.gz to get RG ID\n      var rg_id = (files[i].basename).slice(9,-8);\n      var temp_obj = JSON.parse(chksum_out_json_files[i].contents);\n      metas.push({name: files[i].basename, size: files[i].size, md5: temp_obj.md5sum, sha2: temp_obj.sha2sum, rg_info: rg_dict[rg_id]});\n    }\n    return metas;\n  }\n\n  var final_meta;\n  if (inputs.output_rg_info_file) {\n      final_meta = { input: name_and_chksum(inputs.input_files, inputs.input_chksum_results), output: name_and_checksum_and_rg(inputs.output_files, inputs.output_chksum_results, inputs.output_rg_info_file) };\n  } else {\n      final_meta = { input: name_and_chksum(inputs.input_files, inputs.input_chksum_results), output: name_and_chksum(inputs.output_files, inputs.output_chksum_results) };\n  }\n  return {out_string: JSON.stringify(final_meta)} \n}\n",
            "id": "#results_manifest.cwl"
        },
        {
            "class": "CommandLineTool",
            "inputs": [
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#string_to_file.cwl/in_string"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "results_manifest.json"
                    },
                    "id": "#string_to_file.cwl/outfile"
                }
            ],
            "baseCommand": [
                "echo"
            ],
            "stdout": "results_manifest.json",
            "id": "#string_to_file.cwl"
        }
    ],
    "cwlVersion": "v1.0",
    "$schemas": [
        "http://edamontology.org/EDAM_1.18.owl",
        "https://schema.org/version/latest/schema.rdf"
    ],
    "$namespaces": {
        "s": "http://schema.org/"
    }
}
